# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/audittrails/v1/trail.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/audittrails/v1/trail.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/audittrails/v1/trail.proto\x12\x1byandex.cloud.audittrails.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xcb\x1c\n\x05Trail\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x34\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x05 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12{\n\x06labels\x18\x07 \x03(\x0b\x32..yandex.cloud.audittrails.v1.Trail.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12I\n\x0b\x64\x65stination\x18\x08 \x01(\x0b\x32..yandex.cloud.audittrails.v1.Trail.DestinationB\x04\xe8\xc7\x31\x01\x12$\n\x12service_account_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12?\n\x06status\x18\n \x01(\x0e\x32).yandex.cloud.audittrails.v1.Trail.StatusB\x04\xe8\xc7\x31\x01\x12=\n\x06\x66ilter\x18\x0b \x01(\x0b\x32).yandex.cloud.audittrails.v1.Trail.FilterB\x02\x18\x01\x12\x1c\n\x14status_error_message\x18\x0c \x01(\t\x12\x1e\n\x08\x63loud_id\x18\x0e \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x10\x66iltering_policy\x18\x0f \x01(\x0b\x32\x32.yandex.cloud.audittrails.v1.Trail.FilteringPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x84\x02\n\x0b\x44\x65stination\x12J\n\x0eobject_storage\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.audittrails.v1.Trail.ObjectStorageH\x00\x12H\n\rcloud_logging\x18\x03 \x01(\x0b\x32/.yandex.cloud.audittrails.v1.Trail.CloudLoggingH\x00\x12\x44\n\x0b\x64\x61ta_stream\x18\x04 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.DataStreamH\x00\x42\x13\n\x0b\x64\x65stination\x12\x04\xc0\xc1\x31\x01J\x04\x08\x02\x10\x03\x1a\x43\n\rObjectStorage\x12\x1b\n\tbucket_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04\x33-63\x12\x15\n\robject_prefix\x18\x02 \x01(\t\x1a\x45\n\x0c\x43loudLogging\x12 \n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=64H\x00\x42\r\n\x0b\x64\x65stinationJ\x04\x08\x02\x10\x03\x1a\x36\n\nDataStream\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x1a\x98\x01\n\x06\x46ilter\x12\x42\n\x0bpath_filter\x18\x01 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.PathFilter\x12J\n\x0c\x65vent_filter\x18\x02 \x01(\x0b\x32..yandex.cloud.audittrails.v1.Trail.EventFilterB\x04\xe8\xc7\x31\x01\x1aV\n\nPathFilter\x12H\n\x04root\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.audittrails.v1.Trail.PathFilterElementB\x04\xe8\xc7\x31\x01\x1a\xc4\x01\n\x11PathFilterElement\x12M\n\nany_filter\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.audittrails.v1.Trail.PathFilterElementAnyH\x00\x12O\n\x0bsome_filter\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.audittrails.v1.Trail.PathFilterElementSomeH\x00\x42\x0f\n\x07\x65lement\x12\x04\xc0\xc1\x31\x01\x1a[\n\x14PathFilterElementAny\x12\x43\n\x08resource\x18\x01 \x01(\x0b\x32+.yandex.cloud.audittrails.v1.Trail.ResourceB\x04\xe8\xc7\x31\x01\x1a\xab\x01\n\x15PathFilterElementSome\x12\x43\n\x08resource\x18\x01 \x01(\x0b\x32+.yandex.cloud.audittrails.v1.Trail.ResourceB\x04\xe8\xc7\x31\x01\x12M\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.audittrails.v1.Trail.PathFilterElementB\x06\x82\xc8\x31\x02>0\x1a@\n\x08Resource\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1a\n\x04type\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x1a^\n\x0b\x45ventFilter\x12O\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.audittrails.v1.Trail.EventFilterElementB\x07\x82\xc8\x31\x03>=0\x1a\xd0\x01\n\x12\x45ventFilterElement\x12\x15\n\x07service\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12Y\n\ncategories\x18\x02 \x03(\x0b\x32=.yandex.cloud.audittrails.v1.Trail.EventFilterElementCategoryB\x06\x82\xc8\x31\x02>0\x12H\n\x0bpath_filter\x18\x03 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.PathFilterB\x04\xe8\xc7\x31\x01\x1a\xb7\x01\n\x1a\x45ventFilterElementCategory\x12K\n\x05plane\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.audittrails.v1.Trail.EventCategoryFilterB\x04\xe8\xc7\x31\x01\x12L\n\x04type\x18\x02 \x01(\x0e\x32\x38.yandex.cloud.audittrails.v1.Trail.EventAccessTypeFilterB\x04\xe8\xc7\x31\x01\x1a\x8e\x03\n\x13\x44\x61taEventsFiltering\x12\x15\n\x07service\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12H\n\x0fincluded_events\x18\x02 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.EventTypesH\x00\x12H\n\x0f\x65xcluded_events\x18\x03 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.EventTypesH\x00\x12L\n\ndns_filter\x18\x05 \x01(\x0b\x32\x36.yandex.cloud.audittrails.v1.Trail.DnsDataEventsFilterH\x01\x12P\n\x0fresource_scopes\x18\x04 \x03(\x0b\x32+.yandex.cloud.audittrails.v1.Trail.ResourceB\n\x82\xc8\x31\x06\x31-1024B\x12\n\x10\x61\x64\x64itional_rulesB\x18\n\x16service_specific_rules\x1a-\n\nEventTypes\x12\x1f\n\x0b\x65vent_types\x18\x01 \x03(\tB\n\x82\xc8\x31\x06\x31-1024\x1am\n\x19ManagementEventsFiltering\x12P\n\x0fresource_scopes\x18\x01 \x03(\x0b\x32+.yandex.cloud.audittrails.v1.Trail.ResourceB\n\x82\xc8\x31\x06\x31-1024\x1a\xd6\x01\n\x0f\x46ilteringPolicy\x12\x64\n\x18management_events_filter\x18\x01 \x01(\x0b\x32<.yandex.cloud.audittrails.v1.Trail.ManagementEventsFilteringB\x04\xe8\xc7\x31\x00\x12]\n\x13\x64\x61ta_events_filters\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.audittrails.v1.Trail.DataEventsFilteringB\x08\x82\xc8\x31\x04<128\x1a_\n\x13\x44nsDataEventsFilter\x12\"\n\x16only_recursive_queries\x18\x01 \x01(\x08\x42\x02\x18\x01\x12$\n\x1cinclude_nonrecursive_queries\x18\x02 \x01(\x08\"D\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"_\n\x13\x45ventCategoryFilter\x12%\n!EVENT_CATEGORY_FILTER_UNSPECIFIED\x10\x00\x12\x11\n\rCONTROL_PLANE\x10\x01\x12\x0e\n\nDATA_PLANE\x10\x02\"V\n\x15\x45ventAccessTypeFilter\x12(\n$EVENT_ACCESS_TYPE_FILTER_UNSPECIFIED\x10\x00\x12\t\n\x05WRITE\x10\x01\x12\x08\n\x04READ\x10\x02J\x04\x08\r\x10\x0e\x42r\n\x1fyandex.cloud.api.audittrails.v1B\x02\x41TZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/audittrails/v1;audittrailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.audittrails.v1.trail_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.audittrails.v1B\002ATZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/audittrails/v1;audittrails'
  _globals['_TRAIL_LABELSENTRY']._loaded_options = None
  _globals['_TRAIL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_TRAIL_DESTINATION'].oneofs_by_name['destination']._loaded_options = None
  _globals['_TRAIL_DESTINATION'].oneofs_by_name['destination']._serialized_options = b'\300\3011\001'
  _globals['_TRAIL_OBJECTSTORAGE'].fields_by_name['bucket_id']._loaded_options = None
  _globals['_TRAIL_OBJECTSTORAGE'].fields_by_name['bucket_id']._serialized_options = b'\212\3101\0043-63'
  _globals['_TRAIL_CLOUDLOGGING'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_TRAIL_CLOUDLOGGING'].fields_by_name['log_group_id']._serialized_options = b'\212\3101\004<=64'
  _globals['_TRAIL_FILTER'].fields_by_name['event_filter']._loaded_options = None
  _globals['_TRAIL_FILTER'].fields_by_name['event_filter']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_PATHFILTER'].fields_by_name['root']._loaded_options = None
  _globals['_TRAIL_PATHFILTER'].fields_by_name['root']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_PATHFILTERELEMENT'].oneofs_by_name['element']._loaded_options = None
  _globals['_TRAIL_PATHFILTERELEMENT'].oneofs_by_name['element']._serialized_options = b'\300\3011\001'
  _globals['_TRAIL_PATHFILTERELEMENTANY'].fields_by_name['resource']._loaded_options = None
  _globals['_TRAIL_PATHFILTERELEMENTANY'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_PATHFILTERELEMENTSOME'].fields_by_name['resource']._loaded_options = None
  _globals['_TRAIL_PATHFILTERELEMENTSOME'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_PATHFILTERELEMENTSOME'].fields_by_name['filters']._loaded_options = None
  _globals['_TRAIL_PATHFILTERELEMENTSOME'].fields_by_name['filters']._serialized_options = b'\202\3101\002>0'
  _globals['_TRAIL_RESOURCE'].fields_by_name['id']._loaded_options = None
  _globals['_TRAIL_RESOURCE'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_TRAIL_RESOURCE'].fields_by_name['type']._loaded_options = None
  _globals['_TRAIL_RESOURCE'].fields_by_name['type']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRAIL_EVENTFILTER'].fields_by_name['filters']._loaded_options = None
  _globals['_TRAIL_EVENTFILTER'].fields_by_name['filters']._serialized_options = b'\202\3101\003>=0'
  _globals['_TRAIL_EVENTFILTERELEMENT'].fields_by_name['service']._loaded_options = None
  _globals['_TRAIL_EVENTFILTERELEMENT'].fields_by_name['service']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_EVENTFILTERELEMENT'].fields_by_name['categories']._loaded_options = None
  _globals['_TRAIL_EVENTFILTERELEMENT'].fields_by_name['categories']._serialized_options = b'\202\3101\002>0'
  _globals['_TRAIL_EVENTFILTERELEMENT'].fields_by_name['path_filter']._loaded_options = None
  _globals['_TRAIL_EVENTFILTERELEMENT'].fields_by_name['path_filter']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY'].fields_by_name['plane']._loaded_options = None
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY'].fields_by_name['plane']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY'].fields_by_name['type']._loaded_options = None
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_DATAEVENTSFILTERING'].fields_by_name['service']._loaded_options = None
  _globals['_TRAIL_DATAEVENTSFILTERING'].fields_by_name['service']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL_DATAEVENTSFILTERING'].fields_by_name['resource_scopes']._loaded_options = None
  _globals['_TRAIL_DATAEVENTSFILTERING'].fields_by_name['resource_scopes']._serialized_options = b'\202\3101\0061-1024'
  _globals['_TRAIL_EVENTTYPES'].fields_by_name['event_types']._loaded_options = None
  _globals['_TRAIL_EVENTTYPES'].fields_by_name['event_types']._serialized_options = b'\202\3101\0061-1024'
  _globals['_TRAIL_MANAGEMENTEVENTSFILTERING'].fields_by_name['resource_scopes']._loaded_options = None
  _globals['_TRAIL_MANAGEMENTEVENTSFILTERING'].fields_by_name['resource_scopes']._serialized_options = b'\202\3101\0061-1024'
  _globals['_TRAIL_FILTERINGPOLICY'].fields_by_name['management_events_filter']._loaded_options = None
  _globals['_TRAIL_FILTERINGPOLICY'].fields_by_name['management_events_filter']._serialized_options = b'\350\3071\000'
  _globals['_TRAIL_FILTERINGPOLICY'].fields_by_name['data_events_filters']._loaded_options = None
  _globals['_TRAIL_FILTERINGPOLICY'].fields_by_name['data_events_filters']._serialized_options = b'\202\3101\004<128'
  _globals['_TRAIL_DNSDATAEVENTSFILTER'].fields_by_name['only_recursive_queries']._loaded_options = None
  _globals['_TRAIL_DNSDATAEVENTSFILTER'].fields_by_name['only_recursive_queries']._serialized_options = b'\030\001'
  _globals['_TRAIL'].fields_by_name['folder_id']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRAIL'].fields_by_name['created_at']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['created_at']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL'].fields_by_name['updated_at']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['updated_at']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL'].fields_by_name['name']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_TRAIL'].fields_by_name['description']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_TRAIL'].fields_by_name['labels']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_TRAIL'].fields_by_name['destination']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['destination']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_TRAIL'].fields_by_name['status']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_TRAIL'].fields_by_name['filter']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['filter']._serialized_options = b'\030\001'
  _globals['_TRAIL'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_TRAIL'].fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRAIL']._serialized_start=137
  _globals['_TRAIL']._serialized_end=3796
  _globals['_TRAIL_LABELSENTRY']._serialized_start=890
  _globals['_TRAIL_LABELSENTRY']._serialized_end=935
  _globals['_TRAIL_DESTINATION']._serialized_start=938
  _globals['_TRAIL_DESTINATION']._serialized_end=1198
  _globals['_TRAIL_OBJECTSTORAGE']._serialized_start=1200
  _globals['_TRAIL_OBJECTSTORAGE']._serialized_end=1267
  _globals['_TRAIL_CLOUDLOGGING']._serialized_start=1269
  _globals['_TRAIL_CLOUDLOGGING']._serialized_end=1338
  _globals['_TRAIL_DATASTREAM']._serialized_start=1340
  _globals['_TRAIL_DATASTREAM']._serialized_end=1394
  _globals['_TRAIL_FILTER']._serialized_start=1397
  _globals['_TRAIL_FILTER']._serialized_end=1549
  _globals['_TRAIL_PATHFILTER']._serialized_start=1551
  _globals['_TRAIL_PATHFILTER']._serialized_end=1637
  _globals['_TRAIL_PATHFILTERELEMENT']._serialized_start=1640
  _globals['_TRAIL_PATHFILTERELEMENT']._serialized_end=1836
  _globals['_TRAIL_PATHFILTERELEMENTANY']._serialized_start=1838
  _globals['_TRAIL_PATHFILTERELEMENTANY']._serialized_end=1929
  _globals['_TRAIL_PATHFILTERELEMENTSOME']._serialized_start=1932
  _globals['_TRAIL_PATHFILTERELEMENTSOME']._serialized_end=2103
  _globals['_TRAIL_RESOURCE']._serialized_start=2105
  _globals['_TRAIL_RESOURCE']._serialized_end=2169
  _globals['_TRAIL_EVENTFILTER']._serialized_start=2171
  _globals['_TRAIL_EVENTFILTER']._serialized_end=2265
  _globals['_TRAIL_EVENTFILTERELEMENT']._serialized_start=2268
  _globals['_TRAIL_EVENTFILTERELEMENT']._serialized_end=2476
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY']._serialized_start=2479
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY']._serialized_end=2662
  _globals['_TRAIL_DATAEVENTSFILTERING']._serialized_start=2665
  _globals['_TRAIL_DATAEVENTSFILTERING']._serialized_end=3063
  _globals['_TRAIL_EVENTTYPES']._serialized_start=3065
  _globals['_TRAIL_EVENTTYPES']._serialized_end=3110
  _globals['_TRAIL_MANAGEMENTEVENTSFILTERING']._serialized_start=3112
  _globals['_TRAIL_MANAGEMENTEVENTSFILTERING']._serialized_end=3221
  _globals['_TRAIL_FILTERINGPOLICY']._serialized_start=3224
  _globals['_TRAIL_FILTERINGPOLICY']._serialized_end=3438
  _globals['_TRAIL_DNSDATAEVENTSFILTER']._serialized_start=3440
  _globals['_TRAIL_DNSDATAEVENTSFILTER']._serialized_end=3535
  _globals['_TRAIL_STATUS']._serialized_start=3537
  _globals['_TRAIL_STATUS']._serialized_end=3605
  _globals['_TRAIL_EVENTCATEGORYFILTER']._serialized_start=3607
  _globals['_TRAIL_EVENTCATEGORYFILTER']._serialized_end=3702
  _globals['_TRAIL_EVENTACCESSTYPEFILTER']._serialized_start=3704
  _globals['_TRAIL_EVENTACCESSTYPEFILTER']._serialized_end=3790
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/endpoint/api_endpoint_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/endpoint/api_endpoint_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.endpoint import api_endpoint_pb2 as yandex_dot_cloud_dot_endpoint_dot_api__endpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/endpoint/api_endpoint_service.proto\x12\x15yandex.cloud.endpoint\x1a\x1cgoogle/api/annotations.proto\x1a(yandex/cloud/endpoint/api_endpoint.proto\"0\n\x15GetApiEndpointRequest\x12\x17\n\x0f\x61pi_endpoint_id\x18\x01 \x01(\t\"H\n\x17ListApiEndpointsRequest\x12\x15\n\tpage_size\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x16\n\npage_token\x18\x02 \x01(\tB\x02\x18\x01\"j\n\x18ListApiEndpointsResponse\x12\x35\n\tendpoints\x18\x01 \x03(\x0b\x32\".yandex.cloud.endpoint.ApiEndpoint\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x90\x02\n\x12\x41piEndpointService\x12}\n\x03Get\x12,.yandex.cloud.endpoint.GetApiEndpointRequest\x1a\".yandex.cloud.endpoint.ApiEndpoint\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/endpoints/{api_endpoint_id}\x12{\n\x04List\x12..yandex.cloud.endpoint.ListApiEndpointsRequest\x1a/.yandex.cloud.endpoint.ListApiEndpointsResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/endpointsB_\n\x19yandex.cloud.api.endpointZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.endpoint.api_endpoint_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.endpointZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/endpoint;endpoint'
  _globals['_LISTAPIENDPOINTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPIENDPOINTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\030\001'
  _globals['_LISTAPIENDPOINTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPIENDPOINTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\030\001'
  _globals['_APIENDPOINTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_APIENDPOINTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\036\022\034/endpoints/{api_endpoint_id}'
  _globals['_APIENDPOINTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_APIENDPOINTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\014\022\n/endpoints'
  _globals['_GETAPIENDPOINTREQUEST']._serialized_start=147
  _globals['_GETAPIENDPOINTREQUEST']._serialized_end=195
  _globals['_LISTAPIENDPOINTSREQUEST']._serialized_start=197
  _globals['_LISTAPIENDPOINTSREQUEST']._serialized_end=269
  _globals['_LISTAPIENDPOINTSRESPONSE']._serialized_start=271
  _globals['_LISTAPIENDPOINTSRESPONSE']._serialized_end=377
  _globals['_APIENDPOINTSERVICE']._serialized_start=380
  _globals['_APIENDPOINTSERVICE']._serialized_end=652
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.spqr.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_config__pb2
from yandex.cloud.mdb.spqr.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/mdb/spqr/v1/cluster.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a%yandex/cloud/mdb/spqr/v1/config.proto\x1a*yandex/cloud/mdb/spqr/v1/maintenance.proto\"\xfc\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.mdb.spqr.v1.Cluster.LabelsEntry\x12\x42\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32-.yandex.cloud.mdb.spqr.v1.Cluster.Environment\x12\x38\n\nmonitoring\x18\x08 \x03(\x0b\x32$.yandex.cloud.mdb.spqr.v1.Monitoring\x12\x37\n\x06\x63onfig\x18\t \x01(\x0b\x32\'.yandex.cloud.mdb.spqr.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12\x38\n\x06health\x18\x0b \x01(\x0e\x32(.yandex.cloud.mdb.spqr.v1.Cluster.Health\x12\x38\n\x06status\x18\x0c \x01(\x0e\x32(.yandex.cloud.mdb.spqr.v1.Cluster.Status\x12G\n\x12maintenance_window\x18\r \x01(\x0b\x32+.yandex.cloud.mdb.spqr.v1.MaintenanceWindow\x12I\n\x11planned_operation\x18\x0e \x01(\x0b\x32..yandex.cloud.mdb.spqr.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x0f \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xa0\x02\n\rClusterConfig\x12\x39\n\x0bspqr_config\x18\x01 \x01(\x0b\x32$.yandex.cloud.mdb.spqr.v1.SPQRConfig\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12>\n\x19\x62\x61\x63kup_retain_period_days\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x06\x61\x63\x63\x65ss\x18\x04 \x01(\x0b\x32 .yandex.cloud.mdb.spqr.v1.Access\x12-\n\tsox_audit\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"W\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x12\x15\n\rdata_transfer\x18\x03 \x01(\x08\x12\x12\n\nserverless\x18\x04 \x01(\x08\x42\x61\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=246
  _globals['_CLUSTER']._serialized_end=1266
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=958
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1003
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1005
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1078
  _globals['_CLUSTER_HEALTH']._serialized_start=1080
  _globals['_CLUSTER_HEALTH']._serialized_end=1143
  _globals['_CLUSTER_STATUS']._serialized_start=1145
  _globals['_CLUSTER_STATUS']._serialized_end=1266
  _globals['_MONITORING']._serialized_start=1268
  _globals['_MONITORING']._serialized_end=1329
  _globals['_CLUSTERCONFIG']._serialized_start=1332
  _globals['_CLUSTERCONFIG']._serialized_end=1620
  _globals['_ACCESS']._serialized_start=1622
  _globals['_ACCESS']._serialized_end=1709
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.threads.message_pb2
import yandex.cloud.ai.assistants.v1.threads.message_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class MessageServiceStub:
    """MessageService provides operations for managing messages."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.threads.message_service_pb2.CreateMessageRequest,
        yandex.cloud.ai.assistants.v1.threads.message_pb2.Message,
    ]
    """Create a new message."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.threads.message_service_pb2.GetMessageRequest,
        yandex.cloud.ai.assistants.v1.threads.message_pb2.Message,
    ]
    """Retrieve details of a specific message by its ID."""

    List: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.threads.message_service_pb2.ListMessagesRequest,
        yandex.cloud.ai.assistants.v1.threads.message_pb2.Message,
    ]
    """List messages in a specific thread.
    By default, messages are listed in reverse chronological order, i.e., from the newest to the oldest.
    """

class MessageServiceAsyncStub:
    """MessageService provides operations for managing messages."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.threads.message_service_pb2.CreateMessageRequest,
        yandex.cloud.ai.assistants.v1.threads.message_pb2.Message,
    ]
    """Create a new message."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.threads.message_service_pb2.GetMessageRequest,
        yandex.cloud.ai.assistants.v1.threads.message_pb2.Message,
    ]
    """Retrieve details of a specific message by its ID."""

    List: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.threads.message_service_pb2.ListMessagesRequest,
        yandex.cloud.ai.assistants.v1.threads.message_pb2.Message,
    ]
    """List messages in a specific thread.
    By default, messages are listed in reverse chronological order, i.e., from the newest to the oldest.
    """

class MessageServiceServicer(metaclass=abc.ABCMeta):
    """MessageService provides operations for managing messages."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.assistants.v1.threads.message_service_pb2.CreateMessageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.threads.message_pb2.Message, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.threads.message_pb2.Message]]:
        """Create a new message."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.threads.message_service_pb2.GetMessageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.threads.message_pb2.Message, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.threads.message_pb2.Message]]:
        """Retrieve details of a specific message by its ID."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.threads.message_service_pb2.ListMessagesRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.assistants.v1.threads.message_pb2.Message], collections.abc.AsyncIterator[yandex.cloud.ai.assistants.v1.threads.message_pb2.Message]]:
        """List messages in a specific thread.
        By default, messages are listed in reverse chronological order, i.e., from the newest to the oldest.
        """

def add_MessageServiceServicer_to_server(servicer: MessageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.storage_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class StorageServiceStub:
    """A set of methods to retrieve information about default storages."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetDefault: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.GetDefaultStorageRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage,
    ]
    """Returns the default storage for the specified configuration."""

    BatchGetDefault: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse,
    ]
    """Returns the default storages for the specified configurations."""

class StorageServiceAsyncStub:
    """A set of methods to retrieve information about default storages."""

    GetDefault: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.GetDefaultStorageRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage,
    ]
    """Returns the default storage for the specified configuration."""

    BatchGetDefault: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse,
    ]
    """Returns the default storages for the specified configurations."""

class StorageServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods to retrieve information about default storages."""

    @abc.abstractmethod
    def GetDefault(
        self,
        request: yandex.cloud.baremetal.v1alpha.storage_service_pb2.GetDefaultStorageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage]]:
        """Returns the default storage for the specified configuration."""

    @abc.abstractmethod
    def BatchGetDefault(
        self,
        request: yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse]]:
        """Returns the default storages for the specified configurations."""

def add_StorageServiceServicer_to_server(servicer: StorageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1alpha/config/mysql5_7.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1alpha/config/mysql5_7.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/mysql/v1alpha/config/mysql5_7.proto\x12%yandex.cloud.mdb.mysql.v1alpha.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xd8\x01\n\x0eMysqlConfig5_7\x12K\n\x17innodb_buffer_pool_size\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t>=5242880\x12\x42\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-10000\x12\x35\n\x0flong_query_time\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xff\x01\n\x11MysqlConfigSet5_7\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mysql.v1alpha.config.MysqlConfig5_7\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mysql.v1alpha.config.MysqlConfig5_7\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.mysql.v1alpha.config.MysqlConfig5_7B|\n)yandex.cloud.api.mdb.mysql.v1alpha.configZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha/config;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1alpha.config.mysql5_7_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.mdb.mysql.v1alpha.configZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha/config;mysql'
  _globals['_MYSQLCONFIG5_7'].fields_by_name['innodb_buffer_pool_size']._loaded_options = None
  _globals['_MYSQLCONFIG5_7'].fields_by_name['innodb_buffer_pool_size']._serialized_options = b'\372\3071\t>=5242880'
  _globals['_MYSQLCONFIG5_7'].fields_by_name['max_connections']._loaded_options = None
  _globals['_MYSQLCONFIG5_7'].fields_by_name['max_connections']._serialized_options = b'\372\3071\01010-10000'
  _globals['_MYSQLCONFIG5_7']._serialized_start=159
  _globals['_MYSQLCONFIG5_7']._serialized_end=375
  _globals['_MYSQLCONFIGSET5_7']._serialized_start=378
  _globals['_MYSQLCONFIGSET5_7']._serialized_end=633
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/gpu_cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/gpu_cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import gpu_cluster_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_gpu__cluster__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/compute/v1/gpu_cluster_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a)yandex/cloud/compute/v1/gpu_cluster.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\".\n\x14GetGpuClusterRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"\xb0\x01\n\x16ListGpuClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x17ListGpuClustersResponse\x12\x39\n\x0cgpu_clusters\x18\x01 \x03(\x0b\x32#.yandex.cloud.compute.v1.GpuCluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x02\n\x17\x43reateGpuClusterRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12L\n\x06labels\x18\x04 \x03(\x0b\x32<.yandex.cloud.compute.v1.CreateGpuClusterRequest.LabelsEntry\x12\x0f\n\x07zone_id\x18\x05 \x01(\t\x12G\n\x11interconnect_type\x18\x06 \x01(\x0e\x32,.yandex.cloud.compute.v1.GpuInterconnectType\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x18\x43reateGpuClusterMetadata\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"\x82\x02\n\x17UpdateGpuClusterRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12L\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.compute.v1.UpdateGpuClusterRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x18UpdateGpuClusterMetadata\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"1\n\x17\x44\x65leteGpuClusterRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteGpuClusterMetadata\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"`\n\x1fListGpuClusterOperationsRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n ListGpuClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x1eListGpuClusterInstancesRequest\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"p\n\x1fListGpuClusterInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xa0\x0f\n\x11GpuClusterService\x12\x8b\x01\n\x03Get\x12-.yandex.cloud.compute.v1.GetGpuClusterRequest\x1a#.yandex.cloud.compute.v1.GpuCluster\"0\x82\xd3\xe4\x93\x02*\x12(/compute/v1/gpuClusters/{gpu_cluster_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.compute.v1.ListGpuClustersRequest\x1a\x30.yandex.cloud.compute.v1.ListGpuClustersResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/compute/v1/gpuClusters\x12\xab\x01\n\x06\x43reate\x12\x30.yandex.cloud.compute.v1.CreateGpuClusterRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*&\n\x18\x43reateGpuClusterMetadata\x12\nGpuCluster\x82\xd3\xe4\x93\x02\x1c\"\x17/compute/v1/gpuClusters:\x01*\x12\xbc\x01\n\x06Update\x12\x30.yandex.cloud.compute.v1.UpdateGpuClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*&\n\x18UpdateGpuClusterMetadata\x12\nGpuCluster\x82\xd3\xe4\x93\x02-2(/compute/v1/gpuClusters/{gpu_cluster_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.compute.v1.DeleteGpuClusterRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*1\n\x18\x44\x65leteGpuClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/compute/v1/gpuClusters/{gpu_cluster_id}\x12\xc2\x01\n\x0eListOperations\x12\x38.yandex.cloud.compute.v1.ListGpuClusterOperationsRequest\x1a\x39.yandex.cloud.compute.v1.ListGpuClusterOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/compute/v1/gpuClusters/{gpu_cluster_id}/operations\x12\xbe\x01\n\rListInstances\x12\x37.yandex.cloud.compute.v1.ListGpuClusterInstancesRequest\x1a\x38.yandex.cloud.compute.v1.ListGpuClusterInstancesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/compute/v1/gpuClusters/{gpu_cluster_id}/instances\x12\xb7\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/compute/v1/gpuClusters/{resource_id}:listAccessBindings\x12\xf6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02<\"7/compute/v1/gpuClusters/{resource_id}:setAccessBindings:\x01*\x12\x82\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x94\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02?\":/compute/v1/gpuClusters/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.gpu_cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTGPUCLUSTERSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEGPUCLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEGPUCLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEGPUCLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEGPUCLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/compute/v1/gpuClusters/{gpu_cluster_id}'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/compute/v1/gpuClusters'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateGpuClusterMetadata\022\nGpuCluster\202\323\344\223\002\034\"\027/compute/v1/gpuClusters:\001*'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateGpuClusterMetadata\022\nGpuCluster\202\323\344\223\002-2(/compute/v1/gpuClusters/{gpu_cluster_id}:\001*'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteGpuClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/compute/v1/gpuClusters/{gpu_cluster_id}'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0025\0223/compute/v1/gpuClusters/{gpu_cluster_id}/operations'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['ListInstances']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['ListInstances']._serialized_options = b'\202\323\344\223\0024\0222/compute/v1/gpuClusters/{gpu_cluster_id}/instances'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002:\0228/compute/v1/gpuClusters/{resource_id}:listAccessBindings'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002<\"7/compute/v1/gpuClusters/{resource_id}:setAccessBindings:\001*'
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_GPUCLUSTERSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002?\":/compute/v1/gpuClusters/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETGPUCLUSTERREQUEST']._serialized_start=364
  _globals['_GETGPUCLUSTERREQUEST']._serialized_end=410
  _globals['_LISTGPUCLUSTERSREQUEST']._serialized_start=413
  _globals['_LISTGPUCLUSTERSREQUEST']._serialized_end=589
  _globals['_LISTGPUCLUSTERSRESPONSE']._serialized_start=591
  _globals['_LISTGPUCLUSTERSRESPONSE']._serialized_end=700
  _globals['_CREATEGPUCLUSTERREQUEST']._serialized_start=703
  _globals['_CREATEGPUCLUSTERREQUEST']._serialized_end=997
  _globals['_CREATEGPUCLUSTERREQUEST_LABELSENTRY']._serialized_start=952
  _globals['_CREATEGPUCLUSTERREQUEST_LABELSENTRY']._serialized_end=997
  _globals['_CREATEGPUCLUSTERMETADATA']._serialized_start=999
  _globals['_CREATEGPUCLUSTERMETADATA']._serialized_end=1049
  _globals['_UPDATEGPUCLUSTERREQUEST']._serialized_start=1052
  _globals['_UPDATEGPUCLUSTERREQUEST']._serialized_end=1310
  _globals['_UPDATEGPUCLUSTERREQUEST_LABELSENTRY']._serialized_start=952
  _globals['_UPDATEGPUCLUSTERREQUEST_LABELSENTRY']._serialized_end=997
  _globals['_UPDATEGPUCLUSTERMETADATA']._serialized_start=1312
  _globals['_UPDATEGPUCLUSTERMETADATA']._serialized_end=1362
  _globals['_DELETEGPUCLUSTERREQUEST']._serialized_start=1364
  _globals['_DELETEGPUCLUSTERREQUEST']._serialized_end=1413
  _globals['_DELETEGPUCLUSTERMETADATA']._serialized_start=1415
  _globals['_DELETEGPUCLUSTERMETADATA']._serialized_end=1465
  _globals['_LISTGPUCLUSTEROPERATIONSREQUEST']._serialized_start=1467
  _globals['_LISTGPUCLUSTEROPERATIONSREQUEST']._serialized_end=1563
  _globals['_LISTGPUCLUSTEROPERATIONSRESPONSE']._serialized_start=1565
  _globals['_LISTGPUCLUSTEROPERATIONSRESPONSE']._serialized_end=1679
  _globals['_LISTGPUCLUSTERINSTANCESREQUEST']._serialized_start=1681
  _globals['_LISTGPUCLUSTERINSTANCESREQUEST']._serialized_end=1792
  _globals['_LISTGPUCLUSTERINSTANCESRESPONSE']._serialized_start=1794
  _globals['_LISTGPUCLUSTERINSTANCESRESPONSE']._serialized_end=1906
  _globals['_GPUCLUSTERSERVICE']._serialized_start=1909
  _globals['_GPUCLUSTERSERVICE']._serialized_end=3861
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/trino.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/trino.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/connectionmanager/v1/trino.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"e\n\tTrinoAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xcd\x01\n\x0cTrinoCluster\x12P\n\x0b\x63oordinator\x18\x01 \x01(\x0b\x32;.yandex.cloud.connectionmanager.v1.TrinoCluster.Coordinator\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a)\n\x0b\x43oordinator\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\"\x8f\x01\n\x0fTrinoConnection\x12@\n\x07\x63luster\x18\x01 \x01(\x0b\x32/.yandex.cloud.connectionmanager.v1.TrinoCluster\x12:\n\x04\x61uth\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TrinoAuthB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.trino_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_TRINOAUTH']._serialized_start=132
  _globals['_TRINOAUTH']._serialized_end=233
  _globals['_TRINOCLUSTER']._serialized_start=236
  _globals['_TRINOCLUSTER']._serialized_end=441
  _globals['_TRINOCLUSTER_COORDINATOR']._serialized_start=400
  _globals['_TRINOCLUSTER_COORDINATOR']._serialized_end=441
  _globals['_TRINOCONNECTION']._serialized_start=444
  _globals['_TRINOCONNECTION']._serialized_end=587
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.cdn.v1.origin_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetOriginRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin belongs to."""
    origin_id: builtins.int
    """[origin_id] group ID to request origin from."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "origin_id", b"origin_id"]) -> None: ...

global___GetOriginRequest = GetOriginRequest

@typing.final
class ListOriginsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin belongs to."""
    origin_group_id: builtins.int
    """ID of the group to request origins from."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "origin_group_id", b"origin_group_id"]) -> None: ...

global___ListOriginsRequest = ListOriginsRequest

@typing.final
class ListOriginsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINS_FIELD_NUMBER: builtins.int
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.origin_pb2.Origin]:
        """Origin from response."""

    def __init__(
        self,
        *,
        origins: collections.abc.Iterable[yandex.cloud.cdn.v1.origin_pb2.Origin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origins", b"origins"]) -> None: ...

global___ListOriginsResponse = ListOriginsResponse

@typing.final
class CreateOriginRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    BACKUP_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin belongs to."""
    origin_group_id: builtins.int
    """[origin_group_id] group ID to request origins from."""
    source: builtins.str
    """IP address or Domain name of your origin and the port (if custom).
    Used if [meta] variant is `common`.
    """
    provider_type: builtins.str
    """Set up origin provider

    It has two possible values:

    ourcdn - Based on Yandex technologies
    gcore - Based on an external partner infrastructure

    Default value: ourcdn
    """
    @property
    def enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """The setting allows to enable or disable an Origin source in the Origins group.

        It has two possible values:

        True - The origin is enabled and used as a source for the CDN. An origins
        group must contain at least one enabled origin. Default value.
        False - The origin is disabled and the CDN is not using it to pull content.
        """

    @property
    def backup(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the origin is used in its origin group as backup.
        A backup origin is used when one of active origins becomes unavailable.

        Default value: False.
        """

    @property
    def meta(self) -> yandex.cloud.cdn.v1.origin_pb2.OriginMeta:
        """Set up origin of the content."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_group_id: builtins.int = ...,
        source: builtins.str = ...,
        enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backup: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        meta: yandex.cloud.cdn.v1.origin_pb2.OriginMeta | None = ...,
        provider_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup", b"backup", "enabled", b"enabled", "meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup", b"backup", "enabled", b"enabled", "folder_id", b"folder_id", "meta", b"meta", "origin_group_id", b"origin_group_id", "provider_type", b"provider_type", "source", b"source"]) -> None: ...

global___CreateOriginRequest = CreateOriginRequest

@typing.final
class CreateOriginMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    origin_id: builtins.int
    """ID of the origin."""
    origin_group_id: builtins.int
    """ID pf the parent origins group."""
    def __init__(
        self,
        *,
        origin_id: builtins.int = ...,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id", "origin_id", b"origin_id"]) -> None: ...

global___CreateOriginMetadata = CreateOriginMetadata

@typing.final
class UpdateOriginRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    BACKUP_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin belongs to."""
    origin_id: builtins.int
    """ID of the origin."""
    source: builtins.str
    """PUT behavior, parameter below will be fully rewritten

    IP address or Domain name of your origin and the port (if custom).
    Used if [meta] variant is `common`.
    Required.
    """
    enabled: builtins.bool
    """The setting allows to enable or disable an Origin source in the Origins group.

    It has two possible values:

    True - The origin is enabled and used as a source for the CDN. An origins
    group must contain at least one enabled origin. Default value.
    False - The origin is disabled and the CDN is not using it to pull content.

    Required.
    """
    backup: builtins.bool
    """Specifies whether the origin is used in its origin group as backup.
    A backup origin is used when one of active origins becomes unavailable.

    Required.
    """
    @property
    def meta(self) -> yandex.cloud.cdn.v1.origin_pb2.OriginMeta:
        """Set up type of the origin."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_id: builtins.int = ...,
        source: builtins.str = ...,
        enabled: builtins.bool = ...,
        backup: builtins.bool = ...,
        meta: yandex.cloud.cdn.v1.origin_pb2.OriginMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup", b"backup", "enabled", b"enabled", "folder_id", b"folder_id", "meta", b"meta", "origin_id", b"origin_id", "source", b"source"]) -> None: ...

global___UpdateOriginRequest = UpdateOriginRequest

@typing.final
class UpdateOriginMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    origin_id: builtins.int
    """ID of the origin."""
    origin_group_id: builtins.int
    """Parent origins group ID."""
    def __init__(
        self,
        *,
        origin_id: builtins.int = ...,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id", "origin_id", b"origin_id"]) -> None: ...

global___UpdateOriginMetadata = UpdateOriginMetadata

@typing.final
class DeleteOriginRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin belongs to."""
    origin_id: builtins.int
    """ID of the origin."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "origin_id", b"origin_id"]) -> None: ...

global___DeleteOriginRequest = DeleteOriginRequest

@typing.final
class DeleteOriginMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_ID_FIELD_NUMBER: builtins.int
    origin_id: builtins.int
    """ID of the origin."""
    def __init__(
        self,
        *,
        origin_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origin_id", b"origin_id"]) -> None: ...

global___DeleteOriginMetadata = DeleteOriginMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.classifier_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListClassifiersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """Project id"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___ListClassifiersRequest = ListClassifiersRequest

@typing.final
class ListClassifiersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSIFIERS_FIELD_NUMBER: builtins.int
    @property
    def classifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.classifier_pb2.Classifier]:
        """Classifiers belonging to the given project"""

    def __init__(
        self,
        *,
        classifiers: collections.abc.Iterable[yandex.cloud.speechsense.v1.classifier_pb2.Classifier] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classifiers", b"classifiers"]) -> None: ...

global___ListClassifiersResponse = ListClassifiersResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/mongodb.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/mongodb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/connectionmanager/v1/mongodb.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"g\n\x0bMongoDBAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xe8\x04\n\x0eMongoDBCluster\x12\x45\n\x05hosts\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xcc\x03\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12I\n\x04role\x18\x03 \x01(\x0e\x32;.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host.Role\x12M\n\x06health\x18\x04 \x01(\x0e\x32=.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host.Health\x12I\n\x04type\x18\x05 \x01(\x0e\x32;.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host.Type\"D\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0e\n\nMONGOINFRA\x10\x03\"8\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\r\n\tSECONDARY\x10\x02\"C\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xc4\x01\n\x11MongoDBConnection\x12\x42\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.connectionmanager.v1.MongoDBCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12<\n\x04\x61uth\x18\x03 \x01(\x0b\x32..yandex.cloud.connectionmanager.v1.MongoDBAuth\x12\x11\n\tdatabases\x18\x04 \x03(\tB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.mongodb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_MONGODBAUTH']._serialized_start=134
  _globals['_MONGODBAUTH']._serialized_end=237
  _globals['_MONGODBCLUSTER']._serialized_start=240
  _globals['_MONGODBCLUSTER']._serialized_end=856
  _globals['_MONGODBCLUSTER_HOST']._serialized_start=396
  _globals['_MONGODBCLUSTER_HOST']._serialized_end=856
  _globals['_MONGODBCLUSTER_HOST_TYPE']._serialized_start=661
  _globals['_MONGODBCLUSTER_HOST_TYPE']._serialized_end=729
  _globals['_MONGODBCLUSTER_HOST_ROLE']._serialized_start=731
  _globals['_MONGODBCLUSTER_HOST_ROLE']._serialized_end=787
  _globals['_MONGODBCLUSTER_HOST_HEALTH']._serialized_start=789
  _globals['_MONGODBCLUSTER_HOST_HEALTH']._serialized_end=856
  _globals['_MONGODBCONNECTION']._serialized_start=859
  _globals['_MONGODBCONNECTION']._serialized_end=1055
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RoutingInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RoutingInstance._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: RoutingInstance._Status.ValueType  # 0
        CREATING: RoutingInstance._Status.ValueType  # 1
        UPDATING: RoutingInstance._Status.ValueType  # 2
        DELETING: RoutingInstance._Status.ValueType  # 3
        ACTIVE: RoutingInstance._Status.ValueType  # 4

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: RoutingInstance.Status.ValueType  # 0
    CREATING: RoutingInstance.Status.ValueType  # 1
    UPDATING: RoutingInstance.Status.ValueType  # 2
    DELETING: RoutingInstance.Status.ValueType  # 3
    ACTIVE: RoutingInstance.Status.ValueType  # 4

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class CicPrivateConnectionInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIC_PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
        cic_private_connection_id: builtins.str
        """ID of the cicPrivateConnection that is attached to the routingInstance."""
        def __init__(
            self,
            *,
            cic_private_connection_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["cic_private_connection_id", b"cic_private_connection_id"]) -> None: ...

    @typing.final
    class VpcInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
        AZ_INFOS_FIELD_NUMBER: builtins.int
        vpc_network_id: builtins.str
        """ID of the vpcNetwork that is attached to the routingInstance."""
        @property
        def az_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingInstance.VpcAzInfo]:
            """List of the az-related info about vpcNetworks which are attached to routingInstance"""

        def __init__(
            self,
            *,
            vpc_network_id: builtins.str = ...,
            az_infos: collections.abc.Iterable[global___RoutingInstance.VpcAzInfo] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["az_infos", b"az_infos", "vpc_network_id", b"vpc_network_id"]) -> None: ...

    @typing.final
    class VpcAzInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MANUAL_INFO_FIELD_NUMBER: builtins.int
        @property
        def manual_info(self) -> global___RoutingInstance.VpcManualInfo:
            """VpcInfo which is set by user"""

        def __init__(
            self,
            *,
            manual_info: global___RoutingInstance.VpcManualInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["manual_info", b"manual_info"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["manual_info", b"manual_info"]) -> None: ...

    @typing.final
    class VpcManualInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AZ_ID_FIELD_NUMBER: builtins.int
        PREFIXES_FIELD_NUMBER: builtins.int
        az_id: builtins.str
        """ID of the AZ"""
        @property
        def prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """List of prefixes to announce"""

        def __init__(
            self,
            *,
            az_id: builtins.str = ...,
            prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["az_id", b"az_id", "prefixes", b"prefixes"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    VPC_INFO_FIELD_NUMBER: builtins.int
    CIC_PRIVATE_CONNECTION_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the routingInstance."""
    name: builtins.str
    """Name of the routingInstance.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the routingInstance. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the routingInstance belongs to."""
    region_id: builtins.str
    """ID of the region that the routingInstance belongs to."""
    status: global___RoutingInstance.Status.ValueType
    """Status of the routingInstance."""
    @property
    def vpc_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingInstance.VpcInfo]:
        """List of the info about vpcNetworks which are attached to routingInstance."""

    @property
    def cic_private_connection_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingInstance.CicPrivateConnectionInfo]:
        """List of the info about privateConnections which are attached to routingInstance."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        vpc_info: collections.abc.Iterable[global___RoutingInstance.VpcInfo] | None = ...,
        cic_private_connection_info: collections.abc.Iterable[global___RoutingInstance.CicPrivateConnectionInfo] | None = ...,
        status: global___RoutingInstance.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_info", b"cic_private_connection_info", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "region_id", b"region_id", "status", b"status", "vpc_info", b"vpc_info"]) -> None: ...

global___RoutingInstance = RoutingInstance



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import episode_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_episode__pb2
from yandex.cloud.video.v1 import episode_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/video/v1/episode_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class EpisodeServiceStub(object):
    """Episode management service.
    Provides methods for creating, retrieving, updating, and deleting episodes,
    which represent specific time segments of streams
    that can be individually accessed, managed, and published.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/Get',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__pb2.Episode.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.ListEpisodesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.ListEpisodesResponse.FromString,
                _registered_method=True)
        self.BatchGet = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/BatchGet',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchGetEpisodesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchGetEpisodesResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.CreateEpisodeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/Update',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.UpdateEpisodeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/Delete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.DeleteEpisodeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.BatchDelete = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/BatchDelete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchDeleteEpisodesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.PerformAction = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/PerformAction',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.PerformEpisodeActionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetPlayerURL = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/GetPlayerURL',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodePlayerURLRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodePlayerURLResponse.FromString,
                _registered_method=True)
        self.GetManifests = channel.unary_unary(
                '/yandex.cloud.video.v1.EpisodeService/GetManifests',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeManifestsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeManifestsResponse.FromString,
                _registered_method=True)


class EpisodeServiceServicer(object):
    """Episode management service.
    Provides methods for creating, retrieving, updating, and deleting episodes,
    which represent specific time segments of streams
    that can be individually accessed, managed, and published.
    """

    def Get(self, request, context):
        """Retrieves detailed information about a specific episode by its ID.
        Returns all episode metadata, status, and related information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists all episodes associated with a specific stream or stream line with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGet(self, request, context):
        """Retrieves multiple episodes by their IDs in a specific channel in a single request.
        This is more efficient than making multiple Get requests when retrieving several episodes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a new episode associated with a stream or stream line.
        Episodes can be configured with various settings including title, description,
        time boundaries, and access rights.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing episode's metadata and settings.
        Only fields specified in the field_mask will be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a specific episode by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDelete(self, request, context):
        """Deletes multiple episodes associated with a specific stream or stream line in a single request.
        This is more efficient than making multiple Delete requests when removing several episodes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformAction(self, request, context):
        """Performs a specific action on an episode, such as publishing or unpublishing.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlayerURL(self, request, context):
        """Generates a player URL for watching the episode.
        The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
        For episodes with signed URL access, an expiration duration can be specified.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetManifests(self, request, context):
        """Retrieves the manifest URLs for the episode's media content.
        Manifests provide players with necessary information
        for streaming the content with different quality levels and formats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EpisodeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__pb2.Episode.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.ListEpisodesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.ListEpisodesResponse.SerializeToString,
            ),
            'BatchGet': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGet,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchGetEpisodesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchGetEpisodesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.CreateEpisodeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.UpdateEpisodeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.DeleteEpisodeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDelete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchDeleteEpisodesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'PerformAction': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformAction,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.PerformEpisodeActionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetPlayerURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlayerURL,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodePlayerURLRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodePlayerURLResponse.SerializeToString,
            ),
            'GetManifests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetManifests,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeManifestsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeManifestsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.EpisodeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.video.v1.EpisodeService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class EpisodeService(object):
    """Episode management service.
    Provides methods for creating, retrieving, updating, and deleting episodes,
    which represent specific time segments of streams
    that can be individually accessed, managed, and published.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/Get',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__pb2.Episode.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.ListEpisodesRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.ListEpisodesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/BatchGet',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchGetEpisodesRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchGetEpisodesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.CreateEpisodeRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/Update',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.UpdateEpisodeRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/Delete',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.DeleteEpisodeRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/BatchDelete',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.BatchDeleteEpisodesRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PerformAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/PerformAction',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.PerformEpisodeActionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPlayerURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/GetPlayerURL',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodePlayerURLRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodePlayerURLResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetManifests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.EpisodeService/GetManifests',
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeManifestsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_episode__service__pb2.GetEpisodeManifestsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
